// +build ignore

// This program updates template.go

package main

import (
	"bytes"
	"fmt"
	"log"
	"os"

	"github.com/tdewolff/minify"
	"github.com/tdewolff/minify/css"
	"github.com/tdewolff/minify/html"
)

const code = `package github

// Code below generated by make_template.go DO NOT EDIT.

// Template holds layout for markdown content.
const Template = ` + "`%s`"

func main() {
	tFile, err := os.Open("template.html")
	if err != nil {
		log.Fatalf("failed to read file: %s", err)
	}
	defer tFile.Close()

	gFile, err := os.Create("template.go")
	if err != nil {
		log.Fatalf("failed to create template file: %s", err)
	}
	defer tFile.Close()

	m := minify.New()
	m.AddFunc("text/html", html.Minify)
	m.AddFunc("text/css", css.Minify)

	buf := new(bytes.Buffer)
	if err := m.Minify("text/html", buf, tFile); err != nil {
		log.Fatalf("failed to minify: %s", err)
	}

	fmt.Fprintf(gFile, code, buf.String())
}
